@@ -18,7 +18,7 @@ Pluggable API for creating subshells using different programs, such as bash.
 """
 from rez.rex import RexExecutor, ActionInterpreter, OutputStyle
 from rez.util import shlex_join, is_non_string_iterable
-from rez.backport.shutilwhich import which
+from rez.utils.which import which
 from rez.utils.logging_ import print_warning
 from rez.utils.execution import Popen
 from rez.system import system
